@@ -1,14 +1,14 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
- * fische-3.0
+ * fische-3.1
  * Copyright (C) Marcel Ebmer 2009 <marcel@26elf.at>
  * 
- * fische-3.0 is free software: you can redistribute it and/or modify it
+ * fische-3.1 is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
  * 
- * fische-3.0 is distributed in the hope that it will be useful, but
+ * fische-3.1 is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
@@ -30,11 +30,11 @@ class BlurEngine
 		~BlurEngine();
 		void blur();
 	private:
-		VectorField* vectorfield;
-		SdlScreen* sdlscreen;
-		int x0, y0, xRes, yRes;
-		int cpus;
-		void* buffer;
+		VectorField* __vectorfield;
+		SdlScreen* __sdlscreen;
+		int __x0, __y0, __xRes, __yRes;
+		int __cpus;
+		void* __buffer;
 		void emptyBuffer();
 		void writeBuffer();
 		void blurTrad();
