@@ -1,14 +1,14 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
- * fische-3.0
+ * fische-3.1
  * Copyright (C) Marcel Ebmer 2009 <marcel@26elf.at>
  * 
- * fische-3.0 is free software: you can redistribute it and/or modify it
+ * fische-3.1 is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
  * 
- * fische-3.0 is distributed in the hope that it will be useful, but
+ * fische-3.1 is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
@@ -24,6 +24,10 @@
 #define EXIT 1
 #define PAUSE 2
 #define TOGGLE_FULLSCREEN 4
+#define MOUSE 8
+#define PLUS 16
+#define MINUS 32
+#define TOGGLE_PREDICTIVE 64
 
 class SDL_Surface;
 
@@ -43,9 +47,9 @@ class SdlScreen
 		void toggleFullscreen();
 		
 	private:
-		SDL_Surface *screen;
-		int xRes, yRes;
-		bool fullscreen;
+		SDL_Surface *__screen;
+		int __xRes, __yRes;
+		bool __fullscreen;
 };
 
 
