@@ -1,14 +1,14 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
- * fische-3.0
+ * fische-3.1
  * Copyright (C) Marcel Ebmer 2009 <marcel@26elf.at>
  * 
- * fische-3.0 is free software: you can redistribute it and/or modify it
+ * fische-3.1 is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
  * 
- * fische-3.0 is distributed in the hope that it will be useful, but
+ * fische-3.1 is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
@@ -33,22 +33,23 @@ class VectorField
 		char* get();
 		
 	private:
-		std::vector<char*> field;
+		std::vector<char*> __field;
 		char* fillField(int);
-		char* data;
-		int xRes, yRes;
+		char* __data;
+		int __xRes, __yRes;
 
 		void validateX(int x, char* v)
 		{
 			while(x + *v < 2) (*v)++;
-			while(x + *v > xRes - 3) (*v)--;
+			while(x + *v > __xRes - 3) (*v)--;
 		}
 
 		void validateY(int y, char* v)
 		{
 			while(y + *v < 2) (*v)++;
-			while(y + *v > yRes - 3) (*v)--;
+			while(y + *v > __yRes - 3) (*v)--;
 		}
+		void randomize(char*, int);
 
 };
 
