@@ -1,14 +1,14 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
- * fische-3.0
+ * fische-3.1
  * Copyright (C) Marcel Ebmer 2009 <marcel@26elf.at>
  * 
- * fische-3.0 is free software: you can redistribute it and/or modify it
+ * fische-3.1 is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
  * 
- * fische-3.0 is distributed in the hope that it will be useful, but
+ * fische-3.1 is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
@@ -33,19 +33,23 @@ class WavePainter
 		void paint();
 		void changeColor();
 		void changeShape();
+		void beat(double);
 
 	private:
 		void line(int, int, int, int, uint32_t);
-		int xCenter, yCenter;
-		int height;
-		int width;
-		int x0, y0;
-		SdlScreen* sdlscreen;
-		RingBuffer* ringbuffer;
-		int shape;
-		int shapes;
-		uint32_t color1;
-		uint32_t color2;
+		void segment(double, double, double, double, uint32_t color = 0xffffff00);
+		int __xCenter, __yCenter;
+		int __height;
+		int __width;
+		int __x0, __y0;
+		SdlScreen* __sdlscreen;
+		RingBuffer* __ringbuffer;
+		int __shape;
+		int __shapes;
+		uint32_t __color1;
+		uint32_t __color2;
+		double __alpha;
+		// int __style;
 };
 
 int iround(double);
